#!/bin/bash
# annoy.mod.sh
# -------------
# Dulog module.
# weed out some annoying messages, but make a note of it in the report.
# by Icon Riabitsev <icon@phy.duke.edu>
#
# $Id: annoy.mod.sh,v 1.7 2001/08/30 23:16:58 icon Exp $
#

getboxlist() {
 # $1 should be the file name with log entries
 # produces the list and puts it into $WORKPREFIX.report
 sed "s/.*:[[:digit:]]*:[[:digit:]]* \([^[:space:]]*\) [^[:space:]]*:.*/\1/g; s|/.*||g" $1 | sort | uniq >> $WORKPREFIX.report
}

WORKPREFIX="$TMPPREFIX.annoy"

# look for floppy reports

egrep "02:00: rw=.*, want=.*, limit=.*" $LOGCAT > $WORKPREFIX.flops
if [ -s $WORKPREFIX.flops ]; then
 echo "::Dirty floppy mounts on::" >> $WORKPREFIX.report
 getboxlist $WORKPREFIX.flops
 if [ ! -z "$WEED" ]; then
  sed ': more
      $!N
      s/\n/&/2;
      t enough
      $!b more
      : enough
      /^.*kernel: 02:00: rw.*want.*limit.*\n.*Directory sread.*\n.*beyond end of dev.*$/d
      P;D' $LOGCAT > $LOGCAT.new
  mv $LOGCAT.new $LOGCAT
 fi
fi

#look for CD-ROM loads/unloads
egrep "kernel: Uniform CD-ROM" $LOGCAT > $WORKPREFIX.cdrom
egrep "kernel:.*ATAPI.*CD-ROM" $LOGCAT >> $WORKPREFIX.cdrom
if [ -s $WORKPREFIX.cdrom ]; then
 echo "::CD-ROM activity on::" >> $WORKPREFIX.report
 getboxlist $WORKPREFIX.cdrom
 if [ ! -z "$WEED" ]; then
  egrep -v "kernel: Uniform CD-ROM" $LOGCAT > $WORKPREFIX.1
  egrep -v "kernel:.*ATAPI.*CD-ROM" $WORKPREFIX.1 > $LOGCAT
 fi
fi

#look for SoundCard stuff.
egrep "kernel: [Ss][Bb]" $LOGCAT > $WORKPREFIX.snd
egrep "kernel: es1371" $LOGCAT >> $WORKPREFIX.snd
egrep "kernel: ac97_codec" $LOGCAT >> $WORKPREFIX.snd
if [ -s $WORKPREFIX.snd ]; then
 echo "::SoundCard activity on::" >>  $WORKPREFIX.report
 getboxlist $WORKPREFIX.snd
 if [ ! -z "$WEED" ]; then
  egrep -v "kernel: [Ss][Bb]" $LOGCAT > $LOGCAT.1
  egrep -v "kernel: es1371" $LOGCAT.1 > $LOGCAT.2
  egrep -v "kernel: ac97_codec" $LOGCAT.2 > $LOGCAT
 fi
fi

#look for modules.conf mismatches
egrep "modules.conf is more recent" $LOGCAT > $WORKPREFIX.mod
if [ -s $WORKPREFIX.mod ]; then
 echo "::Need to run depmod on::" >> $WORKPREFIX.report
 getboxlist $WORKPREFIX.mod
 if [ ! -z "$WEED" ]; then
  egrep -v "modules.conf is more recent" $LOGCAT > $LOGCAT.new
  mv $LOGCAT.new $LOGCAT
 fi
fi

# look for fatal X errors on gdm
egrep "gdm.*Fatal X error" $LOGCAT > $WORKPREFIX.gdmx
if [ -s $WORKPREFIX.gdmx ]; then
 echo "::Fatal gdm X errors::" >> $WORKPREFIX.report
 getboxlist $WORKPREFIX.gdmx
 if [ ! -z "$WEED" ]; then
  egrep -v "gdm.*Fatal X error" $LOGCAT > $LOGCAT.new
  mv $LOGCAT.new $LOGCAT
 fi
fi

# look for IRQ finds
egrep "kernel: PCI: Found IRQ" $LOGCAT > $WORKPREFIX.irq
if [ -s $WORKPREFIX.irq ]; then
 echo "::PCI IRQ finds on::" >> $WORKPREFIX.report
 getboxlist $WORKPREFIX.irq
 if [ ! -z "$WEED" ]; then
  egrep -v "kernel: PCI: Found IRQ" $LOGCAT > $LOGCAT.new
  mv $LOGCAT.new $LOGCAT
 fi
fi

if [ -s $WORKPREFIX.report ]; then
 echo -e "\nANNOYANCES\n-------------" >> $LOGREPORT
 cat $WORKPREFIX.report >> $LOGREPORT
fi
